==> perl5.005_58.tar.gz: perl5.005_58/lib/unicode/Is/Print.pl <==
return <<'END';
0020	007e
00a0	01f5
01fa	0217
0250	02a8
02b0	02de
02e0	02e9
0300	0345
0360	0361
0374	0375
037a	
037e	
0384	038a
038c	
038e	03a1
03a3	03ce
03d0	03d6
03da	
03dc	
03de	
03e0	
03e2	03f3
0401	040c
040e	044f
0451	045c
045e	0486
0490	04c4
04c7	04c8
04cb	04cc
04d0	04eb
04ee	04f5
04f8	04f9
0531	0556
0559	055f
0561	0587
0589	
0591	05a1
05a3	05b9
05bb	05c4
05d0	05ea
05f0	05f4
060c	
061b	
061f	
0621	063a
0640	0652
0660	066d
0670	06b7
06ba	06be
06c0	06ce
06d0	06ed
06f0	06f9
0901	0903
0905	0939
093c	094d
0950	0954
0958	0970
0981	0983
0985	098c
098f	0990
0993	09a8
09aa	09b0
09b2	
09b6	09b9
09bc	
09be	09c4
09c7	09c8
09cb	09cd
09d7	
09dc	09dd
09df	09e3
09e6	09fa
0a02	
0a05	0a0a
0a0f	0a10
0a13	0a28
0a2a	0a30
0a32	0a33
0a35	0a36
0a38	0a39
0a3c	
0a3e	0a42
0a47	0a48
0a4b	0a4d
0a59	0a5c
0a5e	
0a66	0a74
0a81	0a83
0a85	0a8b
0a8d	
0a8f	0a91
0a93	0aa8
0aaa	0ab0
0ab2	0ab3
0ab5	0ab9
0abc	0ac5
0ac7	0ac9
0acb	0acd
0ad0	
0ae0	
0ae6	0aef
0b01	0b03
0b05	0b0c
0b0f	0b10
0b13	0b28
0b2a	0b30
0b32	0b33
0b36	0b39
0b3c	0b43
0b47	0b48
0b4b	0b4d
0b56	0b57
0b5c	0b5d
0b5f	0b61
0b66	0b70
0b82	0b83
0b85	0b8a
0b8e	0b90
0b92	0b95
0b99	0b9a
0b9c	
0b9e	0b9f
0ba3	0ba4
0ba8	0baa
0bae	0bb5
0bb7	0bb9
0bbe	0bc2
0bc6	0bc8
0bca	0bcd
0bd7	
0be7	0bf2
0c01	0c03
0c05	0c0c
0c0e	0c10
0c12	0c28
0c2a	0c33
0c35	0c39
0c3e	0c44
0c46	0c48
0c4a	0c4d
0c55	0c56
0c60	0c61
0c66	0c6f
0c82	0c83
0c85	0c8c
0c8e	0c90
0c92	0ca8
0caa	0cb3
0cb5	0cb9
0cbe	0cc4
0cc6	0cc8
0cca	0ccd
0cd5	0cd6
0cde	
0ce0	0ce1
0ce6	0cef
0d02	0d03
0d05	0d0c
0d0e	0d10
0d12	0d28
0d2a	0d39
0d3e	0d43
0d46	0d48
0d4a	0d4d
0d57	
0d60	0d61
0d66	0d6f
0e01	0e3a
0e3f	0e5b
0e81	0e82
0e84	
0e87	0e88
0e8a	
0e8d	
0e94	0e97
0e99	0e9f
0ea1	0ea3
0ea5	
0ea7	
0eaa	0eab
0ead	0eb9
0ebb	0ebd
0ec0	0ec4
0ec6	
0ec8	0ecd
0ed0	0ed9
0edc	0edd
0f00	0f47
0f49	0f69
0f71	0f8b
0f90	0f95
0f97	
0f99	0fad
0fb1	0fb7
0fb9	
10a0	10c5
10d0	10f6
10fb	
1100	1159
115f	11a2
11a8	11f9
1200	1206
1208	1246
1248	
124a	124d
1250	1256
1258	
125a	125d
1260	1286
1288	
128a	128d
1290	12ae
12b0	
12b2	12b5
12b8	12be
12c0	
12c2	12c5
12c8	12ce
12d0	12d6
12d8	12ee
12f0	130e
1310	
1312	1315
1318	131e
1320	1346
1348	135a
1361	137c
1e00	1e9b
1ea0	1ef9
1f00	1f15
1f18	1f1d
1f20	1f45
1f48	1f4d
1f50	1f57
1f59	
1f5b	
1f5d	
1f5f	1f7d
1f80	1fb4
1fb6	1fc4
1fc6	1fd3
1fd6	1fdb
1fdd	1fef
1ff2	1ff4
1ff6	1ffe
2000	200b
2010	2029
2030	2046
2070	
2074	208e
20a0	20ac
20d0	20e1
2100	2138
2153	2182
2190	21ea
2200	22f1
2300	
2302	237a
2400	2424
2440	244a
2460	24ea
2500	2595
25a0	25ef
2600	2613
261a	266f
2701	2704
2706	2709
270c	2727
2729	274b
274d	
274f	2752
2756	
2758	275e
2761	2767
2776	2794
2798	27af
27b1	27be
3000	3037
303f	
3041	3094
3099	309e
30a1	30fe
3105	312c
3131	318e
3190	319f
3200	321c
3220	3243
3260	327b
327f	32b0
32c0	32cb
32d0	32fe
3300	3376
337b	33dd
33e0	33fe
4e00	9fa5
ac00	d7a3
f900	fa2d
fb00	fb06
fb13	fb17
fb1e	fb36
fb38	fb3c
fb3e	
fb40	fb41
fb43	fb44
fb46	fbb1
fbd3	fd3f
fd50	fd8f
fd92	fdc7
fdf0	fdfb
fe20	fe23
fe30	fe44
fe49	fe52
fe54	fe66
fe68	fe6b
fe70	fe72
fe74	
fe76	fefc
ff01	ff5e
ff61	ffbe
ffc2	ffc7
ffca	ffcf
ffd2	ffd7
ffda	ffdc
ffe0	ffe6
ffe8	ffee
fffc	fffd
END

==> perl5.005_62.tar.gz: perl5.005_62/lib/unicode/Is/Print.pl <==
return <<'END';
0020	007e
00a0	021f
0222	0233
0250	02ad
02b0	02ee
0300	034e
0360	0362
0374	0375
037a	
037e	
0384	038a
038c	
038e	03a1
03a3	03ce
03d0	03d7
03da	03f3
0400	0486
0488	0489
048c	04c4
04c7	04c8
04cb	04cc
04d0	04f5
04f8	04f9
0531	0556
0559	055f
0561	0587
0589	058a
0591	05a1
05a3	05b9
05bb	05c4
05d0	05ea
05f0	05f4
060c	
061b	
061f	
0621	063a
0640	0655
0660	066d
0670	06ed
06f0	06fe
0700	070d
0710	072c
0730	074a
0780	07b0
0901	0903
0905	0939
093c	094d
0950	0954
0958	0970
0981	0983
0985	098c
098f	0990
0993	09a8
09aa	09b0
09b2	
09b6	09b9
09bc	
09be	09c4
09c7	09c8
09cb	09cd
09d7	
09dc	09dd
09df	09e3
09e6	09fa
0a02	
0a05	0a0a
0a0f	0a10
0a13	0a28
0a2a	0a30
0a32	0a33
0a35	0a36
0a38	0a39
0a3c	
0a3e	0a42
0a47	0a48
0a4b	0a4d
0a59	0a5c
0a5e	
0a66	0a74
0a81	0a83
0a85	0a8b
0a8d	
0a8f	0a91
0a93	0aa8
0aaa	0ab0
0ab2	0ab3
0ab5	0ab9
0abc	0ac5
0ac7	0ac9
0acb	0acd
0ad0	
0ae0	
0ae6	0aef
0b01	0b03
0b05	0b0c
0b0f	0b10
0b13	0b28
0b2a	0b30
0b32	0b33
0b36	0b39
0b3c	0b43
0b47	0b48
0b4b	0b4d
0b56	0b57
0b5c	0b5d
0b5f	0b61
0b66	0b70
0b82	0b83
0b85	0b8a
0b8e	0b90
0b92	0b95
0b99	0b9a
0b9c	
0b9e	0b9f
0ba3	0ba4
0ba8	0baa
0bae	0bb5
0bb7	0bb9
0bbe	0bc2
0bc6	0bc8
0bca	0bcd
0bd7	
0be7	0bf2
0c01	0c03
0c05	0c0c
0c0e	0c10
0c12	0c28
0c2a	0c33
0c35	0c39
0c3e	0c44
0c46	0c48
0c4a	0c4d
0c55	0c56
0c60	0c61
0c66	0c6f
0c82	0c83
0c85	0c8c
0c8e	0c90
0c92	0ca8
0caa	0cb3
0cb5	0cb9
0cbe	0cc4
0cc6	0cc8
0cca	0ccd
0cd5	0cd6
0cde	
0ce0	0ce1
0ce6	0cef
0d02	0d03
0d05	0d0c
0d0e	0d10
0d12	0d28
0d2a	0d39
0d3e	0d43
0d46	0d48
0d4a	0d4d
0d57	
0d60	0d61
0d66	0d6f
0d82	0d83
0d85	0d96
0d9a	0db1
0db3	0dbb
0dbd	
0dc0	0dc6
0dca	
0dcf	0dd4
0dd6	
0dd8	0ddf
0df2	0df4
0e01	0e3a
0e3f	0e5b
0e81	0e82
0e84	
0e87	0e88
0e8a	
0e8d	
0e94	0e97
0e99	0e9f
0ea1	0ea3
0ea5	
0ea7	
0eaa	0eab
0ead	0eb9
0ebb	0ebd
0ec0	0ec4
0ec6	
0ec8	0ecd
0ed0	0ed9
0edc	0edd
0f00	0f47
0f49	0f6a
0f71	0f8b
0f90	0f97
0f99	0fbc
0fbe	0fcc
0fcf	
1000	1021
1023	1027
1029	102a
102c	1032
1036	1039
1040	1059
10a0	10c5
10d0	10f6
10fb	
1100	1159
115f	11a2
11a8	11f9
1200	1206
1208	1246
1248	
124a	124d
1250	1256
1258	
125a	125d
1260	1286
1288	
128a	128d
1290	12ae
12b0	
12b2	12b5
12b8	12be
12c0	
12c2	12c5
12c8	12ce
12d0	12d6
12d8	12ee
12f0	130e
1310	
1312	1315
1318	131e
1320	1346
1348	135a
1361	137c
13a0	13f4
1401	1676
1680	169c
16a0	16f0
1780	17dc
17e0	17e9
1800	180a
1810	1819
1820	1877
1880	18a9
1e00	1e9b
1ea0	1ef9
1f00	1f15
1f18	1f1d
1f20	1f45
1f48	1f4d
1f50	1f57
1f59	
1f5b	
1f5d	
1f5f	1f7d
1f80	1fb4
1fb6	1fc4
1fc6	1fd3
1fd6	1fdb
1fdd	1fef
1ff2	1ff4
1ff6	1ffe
2000	200b
2010	2029
202f	2046
2048	204d
2070	
2074	208e
20a0	20af
20d0	20e3
2100	213a
2153	2183
2190	21f3
2200	22f1
2300	237b
237d	239a
2400	2426
2440	244a
2460	24ea
2500	2595
25a0	25f7
2600	2613
2619	2671
2701	2704
2706	2709
270c	2727
2729	274b
274d	
274f	2752
2756	
2758	275e
2761	2767
2776	2794
2798	27af
27b1	27be
2800	28ff
2e80	2e99
2e9b	2ef3
2f00	2fd5
2ff0	2ffb
3000	303a
303e	303f
3041	3094
3099	309e
30a1	30fe
3105	312c
3131	318e
3190	31b7
3200	321c
3220	3243
3260	327b
327f	32b0
32c0	32cb
32d0	32fe
3300	3376
337b	33dd
33e0	33fe
3400	4db5
4e00	9fa5
a000	a48c
a490	a4a1
a4a4	a4b3
a4b5	a4c0
a4c2	a4c4
a4c6	
ac00	d7a3
f900	fa2d
fb00	fb06
fb13	fb17
fb1d	fb36
fb38	fb3c
fb3e	
fb40	fb41
fb43	fb44
fb46	fbb1
fbd3	fd3f
fd50	fd8f
fd92	fdc7
fdf0	fdfb
fe20	fe23
fe30	fe44
fe49	fe52
fe54	fe66
fe68	fe6b
fe70	fe72
fe74	
fe76	fefc
ff01	ff5e
ff61	ffbe
ffc2	ffc7
ffca	ffcf
ffd2	ffd7
ffda	ffdc
ffe0	ffe6
ffe8	ffee
fffc	fffd
END
